/* This file is part of the KDE desktop environment

   Copyright (C) 2001, 2002 Michael Brade <brade@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef _KDIRLISTERTEST_H_
#define _KDIRLISTERTEST_H_

#include <qwidget.h>
#include <qstring.h>

#include <kurl.h>
#include <kfileitem.h>

class QPushButton;

class KatalogTest : public QWidget
{
   Q_OBJECT
public:
   KatalogTest( QWidget *parent=0, const char *name=0 );
   ~KatalogTest();
  void customEvent( QCustomEvent * e );

public slots:
   void test();
   void start1();
   void start2();
   void start3();
   void start4();
   void slotFinished(QString);
   void slotCurrentFolder(QString);
   void slotNewItem();

private:
   int m_items;
   QPushButton* p_start3;
   int count;
};

#endif
